ObscureType

Enum ObscureType 

pub enum ObscureType {
    Elided,
    Encrypted,
    Compressed,
}
Types of obscuration that can be applied to envelope elements.

This enum identifies the different ways an envelope element can be obscured. Unlike ObscureAction which is used to perform obscuration operations, ObscureType is used to identify and filter elements based on their obscuration state.

Variants



Elided

The element has been elided, showing only its digest.



Encrypted

The element has been encrypted using symmetric encryption.

This variant is only available when the encrypt feature is enabled.



Compressed

The element has been compressed to reduce its size.

This variant is only available when the compress feature is enabled.